SigningKey

Struct SigningKey 

pub struct SigningKey { /* private fields */ }
An Ed25519 signing key.

This is also called a secret key by other implementations.

Implementations

Source

impl SigningKey

pub fn to_bytes(&self) -> [u8; 32]

Returns the byte encoding of the signing key.

This is the same as .into(), but does not require type inference.

pub fn as_bytes(&self) -> &[u8; 32]

View the byte encoding of the signing key.

pub fn verification_key(&self) -> VerificationKey

Obtain the verification key associated with this signing key.

Source

impl SigningKey

pub fn new<R: RngCore + CryptoRng>(rng: R) -> SigningKey

Generate a new signing key.

pub fn sign(&self, msg: &[u8]) -> Signature

Create a signature on msg using this key.