pub struct VerificationKey { /* private fields */ }Expand description
A valid Ed25519 verification key.
This is also called a public key by other implementations.
This type holds decompressed state used in signature verification; if the
verification key may not be used immediately, it is probably better to use
VerificationKeyBytes, which is a refinement type for [u8; 32].
Consensus properties
Ed25519 checks are described in 5.4.5 of the Zcash protocol specification and in
[ZIP 215]. The verification criteria for an (encoded) verification key A_bytes are:
A_bytesMUST be an encoding of a pointAon the twisted Edwards form of Curve25519, and non-canonical encodings MUST be accepted;
Implementations
Sourceimpl VerificationKey
impl VerificationKey
Sourcepub fn to_bytes(&self) -> [u8; 32]
pub fn to_bytes(&self) -> [u8; 32]
Returns the byte encoding of the verification key.
This is the same as .into(), but does not require type inference.
Sourcepub fn verify(&self, signature: &Signature, msg: &[u8]) -> Result<(), Error>
pub fn verify(&self, signature: &Signature, msg: &[u8]) -> Result<(), Error>
Verify a purported signature on the given msg.
Consensus properties
Ed25519 checks are described in 5.4.5 of the Zcash protocol specification and in
ZIP215. The verification criteria for an (encoded) signature (R_bytes, s_bytes) with
(encoded) verification key A_bytes are:
-
A_bytesandR_bytesMUST be encodings of pointsAandRrespectively on the twisted Edwards form of Curve25519, and non-canonical encodings MUST be accepted; -
s_bytesMUST represent an integersless thanl, the order of the prime-order subgroup of Curve25519; -
the verification equation
[8][s]B = [8]R + [8][k]AMUST be satisfied; -
the alternate verification equation
[s]B = R + [k]A, allowed by RFC 8032, MUST NOT be used.